@@ -1,5 +1,5 @@
 /* GNOME drivemount applet
- * (C) 1999 John Ellis
+ * (C) 2000 John Ellis
  *
  * Author: John Ellis
  *
@@ -102,8 +102,10 @@ static IconData icon_list[] = {
 static gint icon_list_count = 5;
 
 static gint mount_cb(GtkWidget *widget, gpointer data);
+static void eject(DriveData *dd);
 static void dnd_init(DriveData *dd);
 
+
 /*
  *-------------------------------------------------------------------------
  * about dlg
@@ -143,7 +145,8 @@ static void about_cb (AppletWidget *widget, gpointer data)
 static void browse_cb (AppletWidget *widget, gpointer data)
 {
 	DriveData *dd = data;
-	gchar *command;
+	char *str;
+	char *argv[4];
 
 	/* attempt to mount first, otherwise, what is the point? */
 	if(!dd->mounted)
@@ -152,9 +155,20 @@ static void browse_cb (AppletWidget *widget, gpointer data)
 		if (!dd->mounted) return; /* failed to mount, so abort */
 		}
 
-	command = g_strdup_printf("gmc-client --create-window=\"%s\"", dd->mount_point);
- 	gnome_execute_shell (NULL, command);
-	g_free (command);
+	/* Do we have nautilus */
+	str = gnome_is_program_in_path ("nautilus");
+	if (str != NULL) {
+		argv[0] = "nautilus";
+		argv[1] = dd->mount_point;
+		argv[2] = NULL;
+		gnome_execute_async (NULL, 2, argv);
+	} else {
+		argv[0] = "gmc-client";
+		argv[1] = "--create-window";
+		argv[2] = dd->mount_point;
+		argv[3] = NULL;
+		gnome_execute_async (NULL, 3, argv);
+	}
 
 	return;
 	widget = NULL;
@@ -200,7 +214,7 @@ static gint device_is_in_mountlist(DriveData *dd)
 	return found;
 }
 
-static gint get_device(gchar *file)
+static gint get_device(const gchar *file)
 {
 	struct stat file_info;
 	gint t;
@@ -468,10 +482,24 @@ static gint mount_cb(GtkWidget *widget, gpointer data)
 
 	pclose (fp);
 
-	/* now if the mount status is the same print
-	   the returned output from (u)mount, we are assuming an error */
-	if (check == device_is_mounted(dd))
+	dd->mounted = device_is_mounted(dd);
+
+	if (check != dd->mounted)
 		{
+		/* success! */
+		update_pixmap(dd, dd->mounted);
+
+		/* eject after unmounting, if enabled */
+		if (check && dd->auto_eject)
+			{
+			eject(dd);
+			}
+		}
+	else
+		{
+		/* the mount status is the same, print
+		   the returned output from (u)mount, we are assuming an error */
+
 		g_string_prepend(str, _("\" reported:\n"));
 		g_string_prepend(str, command_line);
 		g_string_prepend(str, _("Drivemount command failed.\n\""));
@@ -481,14 +509,12 @@ static gint mount_cb(GtkWidget *widget, gpointer data)
 		}
 
 	g_string_free(str, TRUE);
-	drive_update_cb(dd);
 	return FALSE;
 	widget = NULL;
 }
 
-static void eject_cb(AppletWidget *applet, gpointer data)
+static void eject(DriveData *dd)
 {
-	DriveData *dd = data;
 	gchar command_line[300];
 	gchar buffer[200];
 	gchar dn[200];	/* Devicename */
@@ -531,18 +557,25 @@ static void eject_cb(AppletWidget *applet, gpointer data)
 
 	if (dd->mounted) {
 		g_snprintf (command_line, sizeof(command_line),
-			    "eject -u %s", dn);
+			    "eject -u '%s'", dn);
 		/* perhaps it doesn't like the -u option */
 		if(system (command_line)!=0) {
 			g_snprintf (command_line, sizeof(command_line),
-				    "eject %s", dn);
-			system (command_line);
+				    "eject '%s'", dn);
+			gnome_execute_shell (NULL, command_line);
 		}
 	} else {
-		g_snprintf (command_line, sizeof(command_line), "eject %s", dn);
-		system (command_line);
+		g_snprintf (command_line, sizeof(command_line), "eject '%s'", dn);
+		gnome_execute_shell (NULL, command_line);
 	}
-	
+}
+
+static void eject_cb(AppletWidget *applet, gpointer data)
+{
+	DriveData *dd = data;
+
+	eject(dd);
+
 	return;
         applet = NULL;
 }
@@ -605,9 +638,14 @@ static gint applet_save_session(GtkWidget *widget, gchar *privcfgpath, gchar *gl
 static void destroy_drive_widget(GtkWidget *widget, gpointer data)
 {
 	DriveData *dd = data;
+
 	g_free(dd->mount_point);
+	dd->mount_point = NULL;
 	g_free(dd->mount_base);
+	dd->mount_base = NULL;
+
 	g_free(dd);
+
 	return;
 	widget = NULL;
 }
@@ -625,7 +663,7 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	DriveData *dd;
 	gchar *tmp_path;
 
-	dd = g_new(DriveData, 1);
+	dd = g_new0 (DriveData, 1);
 
 	dd->applet = applet;
 	dd->scale_applet = FALSE;
@@ -649,18 +687,6 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 
 	property_load(APPLET_WIDGET(applet)->privcfgpath, dd);
 
-	dd->button=gtk_button_new();
-	applet_widget_add(APPLET_WIDGET(applet), dd->button);
-	gtk_widget_show(dd->button);
-
-	gtk_signal_connect(GTK_OBJECT(applet),"destroy",
-				GTK_SIGNAL_FUNC(destroy_drive_widget),
-				dd);
-	gtk_signal_connect(GTK_OBJECT(dd->button),"clicked",
-				GTK_SIGNAL_FUNC(mount_cb),
-				dd);
-	dnd_init(dd);
-
 	/* attach applet signals here */
 
 	gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
@@ -677,6 +703,19 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 				dd);
 
 
+
+	dd->button=gtk_button_new();
+	applet_widget_add(APPLET_WIDGET(applet), dd->button);
+	gtk_widget_show(dd->button);
+
+	gtk_signal_connect(GTK_OBJECT(applet),"destroy",
+				GTK_SIGNAL_FUNC(destroy_drive_widget),
+				dd);
+	gtk_signal_connect(GTK_OBJECT(dd->button),"clicked",
+				GTK_SIGNAL_FUNC(mount_cb),
+				dd);
+	dnd_init(dd);
+
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
 					      "browse",
 					      GNOME_STOCK_MENU_OPEN,
@@ -840,3 +879,4 @@ static void dnd_init(DriveData *dd)
 			dnd_drag_begin_cb, dd);
 }
 
+
